@@ -1,7 +1,7 @@
 ################################################################################
 ##
 ##   R package sgee by Gregory Vaughan, Kun Chen, and Jun Yan
-##   Copyright (C) 2017
+##   Copyright (C) 2017-2018
 ##
 ##   This file is part of the R package sgee.
 ##
@@ -53,6 +53,27 @@
 #' out between negative \code{interceptLimit} and positive
 #' \code{interceptLimit}. The default value of \code{NULL} uses the
 #' extendInt functionality.
+#' @param stochastic A numeric value between 0 (exclusive) and 1 (inclusive)
+#' to indicate what proportion of the data should be subsampled
+#' in the stochastic implementation of stagewise approached. The default value
+#' of 1 implements the standard deterministic approach where no subsampling
+#' is done.
+#' @param sampleProb A user provided value dictating the
+#' probability distribution for stochastic stagewise approaches.
+#' \code{sampleProb} can be provided as 1) a vector of
+#' fixed values of length equal to the resposne vector y, 2) a function
+#' that takes in a list of values (full list of values given in details)
+#' and returns a vector of length equal to the response vector y, or 3) the
+#' default value of \code{NULL}, which results in a uniform distribution
+#' @param reSample Parameter indicating how frequently a subsample is
+#' collected in stochastic stagewise approaches. If reSample == 1 then
+#' a subsample is collected every iteration,if reSample == 2 a subsample
+#' is collected every two (i.e every other) iteration. If reSample == 0,
+#' (the default value) then a subsample is only collected once
+#' before any iterations have been done.
+#' @param withReplacement a Logical value indicating if the subsampling in
+#' stochastic stagewise approaches should be done with or without replacement.
+#' Default values is \code{FALSE}.
 #' 
 #' @return A list containing all of the parameter values.
 #' 
@@ -61,7 +82,11 @@
 sgee.control <- function(maxIt = 200 , epsilon = 0.05,
                          stoppingThreshold =  NULL,
                          undoThreshold = 0.005,
-                         interceptLimit = NULL){
+                         interceptLimit = NULL,
+                         stochastic = 1,
+                         sampleProb = NULL,
+                         reSample = 1,
+                         withReplacement = FALSE){
 
     ## some basic checks
     if(epsilon <= 0){
@@ -85,10 +110,25 @@ sgee.control <- function(maxIt = 200 , epsilon = 0.05,
         }
     }
 
+    ##############
+    ## stochastic value indicates whether subsampling is used,
+    ## must be between 0 (exclusive) and 1 (inclusive)
+    if(stochastic>1 | stochastic<=0){
+        stop("paramter 'stochastic' indicates percentage of data being subsample and must be greater than 0 and less than or equal to 1")
+    }
+    if(reSample <0 | reSample %% 1 != 0){
+        stop("parameter 'reSample' indicates how frequently a subsample is collected (i.e. reSample == 1 implies every iteration, reSample == 2 implies every other iteration). Therefore, reSample must be a non-negative integer")
+    }
+    
+
     list(maxIt = maxIt,
          epsilon = epsilon,
          stoppingThreshold = stoppingThreshold,
-         undoThreshold = undoThreshold)
+         undoThreshold = undoThreshold,
+         stochastic = stochastic,
+         sampleProb = sampleProb,
+         reSample = reSample,
+         withReplacement = withReplacement)
 }
 
 
